@@ -1,4 +1,4 @@
-package Pcore::DBD v0.4.0;
+package Pcore::DBD v0.5.0;
 
 use Pcore -dist, -role;
 use Pcore::Util::Text qw[escape_scalar];
@@ -246,7 +246,7 @@ sub _default_attr {
         AutoCommit         => 1,
         Callbacks          => {
             connected => sub {
-                P->log->debug( 'Connected to: ' . $_[1] );
+                P->log->sendlog( 'Pcore-DBD', 'Connected to: ' . $_[1] );
 
                 return;
             },
@@ -254,13 +254,13 @@ sub _default_attr {
                 return;
             },
             do => sub {
-                P->log->debug( 'Do: ' . $_[1] );
+                P->log->sendlog( 'Pcore-DBD', 'Do: ' . $_[1] );
 
                 return;
             },
             ChildCallbacks => {
                 execute => sub {
-                    P->log->debug( 'Execute: ' . $_[0]->{Statement} );
+                    P->log->sendlog( 'Pcore-DBD', 'Execute: ' . $_[0]->{Statement} );
 
                     return;
                 }
